/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.model;

import java.awt.Component;
import java.awt.Graphics;
import javax.swing.Icon;
import org.netbeans.spi.actions.AbstractSavable;

/**
 * adds a FarmID to AbstractSavable so we can filter by farm/project.
 * 
 * @author johan
 */
public abstract class EntitySavable extends AbstractSavable implements Icon {
    private final FarmID farmID;
    private final Icon icon;
    
    public EntitySavable(Entity entity, Icon icon) {
        this.farmID = new FarmID(entity.getURI());
        this.icon = icon;
    }
    
    public FarmID getFarmID() {
        return farmID;
    }
    
    // cancel save: unregister and remove from lookups
    public abstract void destroy();

    // optionally dispose enclosing object
    // e.g. dispose/invalidate dataobject upon closing project.
    public void dispose() {}
    
    @Override
    public void paintIcon(Component c, Graphics g, int x, int y) {
        icon.paintIcon(c, g, x, y);
    }

    @Override
    public int getIconWidth() {
        return icon.getIconWidth();
    }

    @Override
    public int getIconHeight() {
        return icon.getIconHeight();
    }
}
