/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.model;

import java.util.HashMap;
import java.util.regex.Pattern;
import org.openide.util.NbBundle;

/**
 * <p>Validator for postal codes</p>
 *
 * Is able to validate postal for a country
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages({"PostalCodeValidator no valid postal code=Invalid postal code for {0}"})
public class PostalCodeValidator {

    private HashMap<Country, String> postalcodePatterns = new HashMap<>();

    public PostalCodeValidator() {
        postalcodePatterns.put(Country.NL, "[0-9]{4}s*[a-zA-Z]{2}$");
        postalcodePatterns.put(Country.JP, "\\d{3}-\\d{4}$");
        postalcodePatterns.put(Country.US, "^\\d{5}\\p{Punct}?\\s?(?:\\d{4})?$");
    }

    /**
     * Validate the postal code Checks if there is a validator available for
     * this country<br/> If there is no validator will not validate
     *
     * @param country
     * @throws validationException when validation fails
     */
    public void validate(Country country, String toValidate) throws ValidationException {
        String pattern = postalcodePatterns.get(country);
        if (pattern != null && !pattern.isEmpty()) {
            Pattern postalCodePattern = Pattern.compile(pattern);
            if (!postalCodePattern.matcher(toValidate).find()) {
                throw new ValidationException(Bundle.PostalCodeValidator_no_valid_postal_code(country.getName()));
            }
        }
    }

    /**
     * Exception to be thrown when validation fails
     *
     * @author merijn
     */
    public class ValidationException extends Exception {

        public ValidationException(String message, Throwable cause, boolean enableSuppression, boolean writableStackTrace) {
            super(message, cause, enableSuppression, writableStackTrace);
        }

        public ValidationException(Throwable cause) {
            super(cause);
        }

        public ValidationException(String message, Throwable cause) {
            super(message, cause);
        }

        public ValidationException(String message) {
            super(message);
        }

        public ValidationException() {
        }
    }
}
